OC.L10N.register(
    "calendar",
    {
    "Calendar" : "日曆",
    "Individual" : "個人",
    "Group" : "群組",
    "Resource" : "資源",
    "Room" : "房間",
    "Unknown" : "未知",
    "Required" : "必須",
    "Does not attend" : "不出席",
    "Please create a calendar first." : "請先創建日曆",
    "New event" : "新活動",
    "group" : "組別",
    "Attendees" : "出席者",
    "Reminders" : "提示",
    "Repeating" : "重複",
    "None" : "空",
    "Every day" : "每日",
    "Every week" : "每星期",
    "Every month" : "每月",
    "Every year" : "每年",
    "never" : "永不",
    "At time of event" : "活動開始的時間",
    "5 minutes before" : "5 分鐘前",
    "10 minutes before" : "10 分鐘前",
    "15 minutes before" : "15 分鐘前",
    "30 minutes before" : "30 分鐘前",
    "1 hour before" : "1 小時前",
    "2 hours before" : "2 小時前",
    "Custom" : "自訂",
    "Audio" : "聲音",
    "sec" : "秒",
    "min" : "分鐘",
    "hours" : "小時",
    "days" : "天",
    "week" : "星期",
    "before" : "之前",
    "start" : "開始",
    "end" : "結束",
    "Week {number} of {year}" : "{year} 年的第 {number} 週",
    "Title of the Event" : "活動標題",
    "All day Event" : "全日活動",
    "Delete" : "刪除",
    "Cancel" : "取消",
    "More ..." : "更多 ...",
    "Create" : "新增",
    "Update" : "更新",
    "Close" : "關閉",
    "Location" : "位置",
    "Description" : "描述",
    "Export" : "滙出",
    "Day" : "日",
    "Week" : "星期",
    "Month" : "月",
    "Today" : "今天",
    "Share Calendar" : "共享日曆",
    "Shared" : "已分享",
    "More" : "更多",
    "Edit" : "編輯",
    "Download" : "下載",
    "Share with users or groups" : "共享于用戶或組別",
    "can edit" : "可編輯",
    "New Calendar" : "新日曆",
    "Name" : "名稱",
    "New Subscription" : "新訂閱",
    "Edit event" : "編輯活動",
    "Delete Event" : "刪除活動",
    "Save Event" : "儲存活動",
    "Time" : "時間",
    "Type" : "類別",
    "Relative" : "相對",
    "Absolute" : "絶對",
    "Repeat" : "重複",
    "Add" : "新增",
    "from" : "由",
    "to" : "至",
    "Reset repeating rule" : "重置重複規則",
    "Repeat every ..." : "重複每 ...",
    "end repeat ..." : "重複結束 ...",
    "times" : "次",
    "Import Calendars" : "滙入日曆",
    "Import canceled" : "滙入取消",
    "Analyzing calendar" : "分析日曆",
    "New calendar" : "新日曆",
    "Import calendar" : "滙入日曆"
},
"nplurals=1; plural=0;");
